`timescale 1ns / 1ns

/** nut_filter
 * The filter that is at the nut of the string.  This filter simply
 * inverts the input data and does no further filtering
 * 
 * Signals:
 * CLK      master clock
 * 
 * RST      active high reset
 * 
 * ENABLE   signal that the current sample should be run through the filter
 * 
 * DATA_IN  input signal to the filter
 * 
 * DATA_OUT result of running the filter on the previous sample
 */

module nut_filter (CLK, RST, ENABLE, DATA_IN, DATA_OUT);

   input CLK;
   input RST;
   input ENABLE;
   
   wire  CLK;
   wire  RST;
   wire  ENABLE;

   input [0:15] DATA_IN;
   output [0:15] DATA_OUT;

   wire [0:15] 	 DATA_IN;
   reg [0:15] 	 DATA_OUT;

   reg [0:15] 	 saved_data;
   
   always @(posedge CLK) 
	 begin
		if (RST) 
		  begin
			 saved_data <= 0;
			 DATA_OUT <= 0;
		  end
		else 
		  begin
			 if (ENABLE) 
			   begin
				  // 2's compliment negation
				  saved_data <= DATA_IN;
				  DATA_OUT <= ~saved_data + 1;
			   end
		  end // else: !if(RST)
	 end // always @ (posedge CLK)
   

endmodule
