`timescale 1ns / 1ns

/**
 * a block of ram so that the XST synthesizer would infer that this
 * is a block ram instead of making a select ram.  This was made
 * to try and keep this design reasonably portable between synthesizers
 * and implementation tools.
 * 
 * Signals:
 * 
 * CLK  assumed 50MHz clock
 *
 * WE   write enable
 * 
 * A    8-bit address
 * 
 * DI   16-bit data in
 * 
 * DO   16-bit data out
 */

module ram_block(CLK, WE, A, DI, DO);
   input           CLK;
   input           WE;
   input [0:7]     A;
   input [0:15]    DI;
   output [0:15]   DO;

   wire            CLK;
   wire            WE;
   wire [0:7]      A;
   wire [0:15]     DI;
   wire [0:15]     DO;

   reg [0:7]       a_reg;
   reg [0:15]      ram[0:255];

   always @(posedge CLK)
     begin
        if(WE)
          ram[A] <= DI;
        a_reg <= A;
     end

   assign DO = ram[a_reg];

endmodule // ram_block
